/*
   netrik -- The ANTRIK Internet Viewer
   Copyright (C) Olaf D. Buddenhagen AKA antrik, et al (see AUTHORS)
   Published under the GNU GPL; see LICENSE for details.
*/
/*
 * url-history.c -- data structure and functions necessary for "back" and
 * related commands
 *
 * (C) 2002 antrik
 *
 * Defines a list containing information about all pages in history, and a
 * function for adding a new page.
 */
#include <stdlib.h>
#include <stdio.h>

#include "debug.h"
#include "layout.h"
#include "url-history.h"

struct Page_list	page_list={
   0,    /* count */
   -1,    /* pos */
   NULL    /* **page */
};

/* Create a new entry in page list, after the one of the currently active page;
 * set the new one as current. */
void add_page(void)
{
   struct Page	*new_page;

   /* resize array to hold all pages */
   page_list.page=realloc(page_list.page, (page_list.count=page_list.pos+1)*sizeof(struct Page *));
   if(page_list.page==NULL) {
      fprintf(stderr, "memory allocation error while storing url to history\n");
      exit(1);
   }

   /* create new page descriptor */
   new_page=page_list.page[page_list.pos]=malloc(sizeof(struct Page));
   if(new_page==NULL) {
      fprintf(stderr, "memory allocation error while preparing page load\n");
      exit(2);
   }

   /* init pager */
   new_page->pager_pos=0;    /* beginning of page will be shown in pager after loading */
   new_page->active_link=-1;    /* no link highlighted */
   new_page->active_anchor=-1;    /* no anchor marked */

   new_page->mark=0;    /* new pages not marked */
}

/* free all memory used by page descriptors and by page list struct itself */
void free_page_list(void)
{
   int	del_page;

   DMSG(("  freeing memory used by page descriptors...\n"));
   for(del_page=0; del_page<page_list.count; ++del_page)
      free_page(page_list.page[del_page]);

   DMSG(("  freeing memory used by list...\n"));
   free(page_list.page);
}
